``xp klip``
===========

Apply Karhunen-Loève Image Projection starlight subtraction and angular differential imaging to either a collection of FITS files representing a sequence of ADI observations, or to a cube of observations with corresponding angle information in a multi-extension FITS file.


.. argparse::
    :ref: xpipeline.commands.klip._docs_args
    :prog: xp klip
    :passparser:
